@@ -231,19 +231,12 @@ if ($App->getParam('SKIN')) {
 $App->log("TPL $App->view",2,'SPAF2');
 $App->template = $App->view;
 // header and footer relative to template_root
-if (file_exists($MODULE.'/'.$App->TPL->getTemplateDir(0).'./header.tpl'));
-                $App->compile($App->TPL->getTemplateDir(0).'/header.tpl');
-
+$App->compile($App->TPL->getTemplateDir(0).'/header.tpl');
+// Append '.tpl' extension
 if (! preg_match('/\.[[:alnum:]]{1,3}$/',$App->template))
      $App->template .= '.tpl';
 $App->compile($App->TPL->getTemplateDir(0).'/'.$App->template);
-
-if (file_exists($App->TPL->getTemplateDir(0).'/footer.tpl'));
-                $App->compile($App->TPL->getTemplateDir(0).'/footer.tpl');
-
-// store current action
-$App->setSession('LAST_ACTION',$CURRENT_ACTION);
-
+$App->compile($App->TPL->getTemplateDir(0).'/footer.tpl');
 
 // return the response
 $App->display();
