@@ -90,9 +90,16 @@ class ApplicationConfig
         if (! $fd = @fopen ($cfile, "r")) {
             $dir = $_SERVER['SCRIPT_FILENAME'];
             $script_path = dirname($dir);
-	        Application::Log('Cannot open config file: '.$script_path. '/'.$cfile);
+	        error_log('Cannot open config file: '.$script_path. '/'.$cfile);
             die ("Cannot open config file.\n");
         }
+        $env = array();
+        foreach (array('BASE_URL') as $varname) {
+                if(getenv($varname) != FALSE) {
+                    $env['${'.$varname.'}'] = getenv($varname);
+                }
+        }
+
         while (!feof ($fd)) {
             $buffer = fgets($fd, 255);
             if (preg_match("/^#/",$buffer)) continue;
@@ -100,7 +107,7 @@ class ApplicationConfig
             list($param,$value) = preg_split ("/\s*=\s*/",$buffer,2);
             if (! $param)
                 continue;
-            $this->parameters[$param] = rtrim($value);
+            $this->parameters[$param] = strtr(rtrim($value), $env);
         }
         fclose($fd);
 
