@@ -43,12 +43,12 @@ $searchstring = uniqid('dummy_');
 $search_limit = 1;
 
 $queryId = sha1($searchstring);
-$SimpleQuery = new Query($queryId,$searchstring);
+$SimpleQuery = new Query($queryId,$archive,$searchstring);
 
 try {
-    $QueryResult = $Backend->query($SimpleQuery,0,$search_limit);
+    $QueryResult = $Backend->query($archive,$SimpleQuery,0,$search_limit);
     // clear flag
-    $App->delSession('ENABLE_CACHE_WARMING_REQUEST');
+    $App->unsetSession('ENABLE_CACHE_WARMING_REQUEST');
     print $QueryResult->numAll();
     exit;
 }
