@@ -3,8 +3,8 @@
 $container = $App->getParam('container');
 
 $Backend = $App->getSession('Backend');
-$Backend->archive = $container;
 $App->setSession('Backend',$Backend);
+$App->setSession('archive',$container);
 $App->setSession('bennoIdTable',array());
 
 exit;
