@@ -31,7 +31,7 @@
  * Suite 330, Boston, MA  02111-1307  USA
  */
 require_once 'model/AppState.php';
-$AppState = new AppState('searchMaskState',$USER->id,$App->getSession('searchMaskState'));
+$AppState = new AppState($USER->id,'searchMaskState',$App->getSession('searchMaskState'));
 $AppState->save();
 
 try {
@@ -43,7 +43,7 @@ catch (Exception $e) {
 $messages = array(
     'MSG'       => 'MSG_LOGOUT',
     'SKIN'      => $App->getSession('SKIN'),
-    'language'  => $App->getSession('LANG')
+    'LANG'      => $App->getSession('LANG')
 );
 
 $App->setSession('User','');
