@@ -40,13 +40,12 @@ class Backend
 {
 
     var $base_url;
-    var $archive;
     var $filter;        // filter assign to each query
     var $rest_user;
     var $rest_pass;
     var $_curl;
 
-    function Backend ($base_url,$archive,$filter)
+    function Backend ($base_url,$filter)
     {
         global $App;
         $this->rest_user = 'benno2';
@@ -54,7 +53,6 @@ class Backend
         $this->rest_ssl_verify = $App->getConfig('REST_SSL_VERIFY');
 
         $this->base_url = $base_url;
-        $this->archive  = $archive;
         $this->filter = $filter;
     }
 
@@ -62,17 +60,18 @@ class Backend
     /**
      * Fetch one email from backend
      *
+     * @param string $archive
      * @param string $sessionMailId
      * @return object $EMail
      */
-    function fetch ($sessionMailId)
+    function fetch ($archive,$sessionMailId)
     {
         global $App;
         $bennoId = QueryResult::getBennoId($sessionMailId);
         $App->log("Fetch mail from archive: $bennoId",3,'Backend');
 
         $request_url  = $this->base_url.'/mail/';
-        $query_string = 'archive='.$this->archive.
+        $query_string = 'archive='.$archive.
 //                        '&filterQuery='.$this->filter.
                         '&id='.$bennoId;
 
@@ -81,7 +80,7 @@ class Backend
         $body   = $maildata['body'];
         $header = $maildata['header'];
 
-        $EMail = new EMail($sessionMailId,$bennoId,$header['From'],$header['To'],$header['Cc'],$header['Bcc'],$header['Subject'],$header['Date'],$header['Size'],$body);
+        $EMail = new EMail($sessionMailId,$archive,$bennoId,$header['From'],$header['To'],$header['Cc'],$header['Bcc'],$header['Subject'],$header['Date'],$header['Size'],$body);
         $EMail->verified = $header['HashCheckPassed'];
 
         foreach ($maildata['attachments'] as $atm) {
@@ -96,6 +95,7 @@ class Backend
     /**
      * Fetch the headers of an email from backend
      *
+     * @param string $archive
      * @param string $sessionMailId
      * @return array $headers
      */
@@ -104,7 +104,7 @@ class Backend
         $bennoId = QueryResult::getBennoId($sessionMailId);
 
         $request_url  = $this->base_url.'/mail/';
-        $query_string = 'archive='.$this->archive.
+        $query_string = 'archive='.$archive.
 //                        '&filterQuery='.$this->filter.
                         '&id='.$bennoId.
                         '&format=headers';
@@ -118,15 +118,16 @@ class Backend
     /**
      * Fetch one email in raw format from backend
      *
+     * @param string $archive
      * @param string $sessionMailId
      * @return string $maildata
      */
-    function fetchRaw ($sessionMailId,$recodeToUTF8=false)
+    function fetchRaw ($archive,$sessionMailId,$recodeToUTF8=false)
     {
         $bennoId = QueryResult::getBennoId($sessionMailId);
 
         $request_url  = $this->base_url.'/mail/';
-        $query_string = 'archive='.$this->archive.
+        $query_string = 'archive='.$archive.
 //                        '&filterQuery='.$this->filter.
                         '&id='.$bennoId.
                         '&format=raw';
@@ -144,15 +145,16 @@ class Backend
     /**
      * Fetch attachment from backend
      *
+     * @param string $archive
      * @param string $mailId
      * @return object $EMail
      */
-    function fetchAttachment ($sessionMailId,$filename)
+    function fetchAttachment ($archive,$sessionMailId,$filename)
     {
         $bennoId = QueryResult::getBennoId($sessionMailId);
 
         $request_url  = $this->base_url.'/attachment/';
-        $query_string = 'archive='.$this->archive.
+        $query_string = 'archive='.$archive.
                         '&id='.$bennoId.
                         '&attachment='.$filename;
 
@@ -197,7 +199,7 @@ class Backend
      * @param int $limit (default: 20)
      * @return array $EMail objects
      */
-    function query ($Query,$startNum=0,$limit=20)
+    function query ($archive,$Query,$startNum=0,$limit=20)
     {
         global $App;
         global $Audit;
@@ -207,7 +209,7 @@ class Backend
         }
 
         $request_url  = $this->base_url.'/search/';
-        $query = 'archive='.$this->archive .
+        $query = 'archive='.$archive .
                  '&filterQuery='.$this->filter .
                  '&limit='.$limit .
                  '&start='.$startNum .
@@ -226,7 +228,7 @@ class Backend
                 throw new Exception('LICENSE_ERROR');
             }
         }
-        $Audit->log("QUERY $this->archive:".$Query->getQuery().' && '.$this->filter);
+        $Audit->log("QUERY $archive:".$Query->getQuery().' && '.$this->filter);
 
         $QueryResult = new QueryResult($resultList,$Query,$limit);
         return $QueryResult;
@@ -272,7 +274,7 @@ class Backend
             }
         }
 
-         $App->log('Request URL: '.$request_url."?".$query,4,'Backend');
+        $App->log('Request URL: '.$request_url."?".$query,4,'Backend');
         if (($response = curl_exec($curl)) === false) {
             $errnum = curl_errno($curl);
             $App->log('[Backend/query] Request error: '.curl_error($curl).'['.$errnum.']');
