@@ -36,7 +36,7 @@ class MailObject
 {
 
     var $id;        // searchId
-    var $bennoId;   // repo id
+    var $permaId;   // id to access email: base64(<box>:<bennoId>@<archive>)
     var $from;
     var $to;
     var $cc;
@@ -49,10 +49,10 @@ class MailObject
     var $bodytype;
 
 
-    function MailObject($id,$bennoId,$from='',$to='',$cc='',$bcc='',$subject='',$date='',$time='',$size='',$body='',$attachments=array())
+    function MailObject($id,$permaId,$from='',$to='',$cc='',$bcc='',$subject='',$date='',$time='',$size='',$body='',$attachments=array())
     {
         $this->id       = $id; 
-        $this->id       = $bennoId; 
+        $this->permaId  = $permaId;
         $this->from     = $from;
         $this->to       = $to;
         $this->cc       = $cc;
