@@ -30,16 +30,14 @@
  * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
  * Suite 330, Boston, MA  02111-1307  USA
  */
-include_once 'model/Backend.php';
 include_once 'model/MailObject.php';
 
 $QueryResult = $App->getSession('QueryResult');
-$Backend     = $App->getSession('Backend');
 
 $sessionMailId = $App->getParam('id');
 
 try {
-    $EMail = $Backend->fetch($sessionMailId);
+    $EMail = $Backend->fetch($archive,$sessionMailId);
     $App->setSession('sessionMailId',$sessionMailId);
     $App->setSession('EMail',$EMail);
 }
@@ -47,7 +45,8 @@ catch (Exception $e) {
     $App->log($e->getMessage());
 }
 
-$MailObject = new MailObject($EMail->id,$EMail->bennoId);
+$permaId = base64_encode($EMail->bennoId.'@'.$EMail->archive);
+$MailObject = new MailObject($EMail->id,$permaId);
 $MailObject->from       = $EMail->getFrom();
 $MailObject->to         = $EMail->getTo();
 $MailObject->cc         = $EMail->getCc();
