@@ -64,7 +64,10 @@ $App->assign('DATEPICKER_POPUP',$App->getConfig('DATEPICKER_POPUP','both'));
 
 
 // load mail in content area
-$App->assign('currentMailId',$sessionMailId);
+if ($sessionMailId) {
+    $App->assign('showMailContent','TRUE');
+    $App->assign('currentMailId',$sessionMailId);
+}
 
 if (isset($queryId)) // display current stored query
     $App->assign('queryId',$queryId);
